@@ -22,14 +22,13 @@
    Author: Ettore Perazzoli <ettore@comm2000.it>
 */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
+#include "gnome-vfs-file-info.h"
 
+#include <glib/gmessages.h>
+#include <glib/gstrfuncs.h>
+#include <glib/gthread.h>
 #include <string.h>
-#include <glib.h>
-#include "gnome-vfs.h"
-#include "gnome-vfs-private.h"
 
 /* Mutex for making GnomeVFSFileInfo ref's/unref's atomic */
 /* Note that an atomic increment function (such as is present in NSPR) is preferable */
@@ -38,11 +37,11 @@ static GStaticMutex file_info_ref_lock = G_STATIC_MUTEX_INIT;
 
 
 /**
- * gnome_vfs_file_info_new:
+ * gnome_vfs_file_info_new
  * 
  * Allocate and initialize a new file information struct.
  * 
- * Return value: A pointer to the new file information struct.
+ * Returns: A pointer to the new file information struct.
  **/
 GnomeVFSFileInfo *
 gnome_vfs_file_info_new (void)
@@ -61,7 +60,7 @@ gnome_vfs_file_info_new (void)
 
 
 /**
- * gnome_vfs_file_info_ref:
+ * gnome_vfs_file_info_ref
  * @info: Pointer to a file information struct
  * 
  * Increment reference count
@@ -79,7 +78,7 @@ gnome_vfs_file_info_ref (GnomeVFSFileInfo *info)
 }
 
 /**
- * gnome_vfs_file_info_unref:
+ * gnome_vfs_file_info_unref
  * @info: Pointer to a file information struct
  * 
  * Destroy @info
@@ -102,7 +101,7 @@ gnome_vfs_file_info_unref (GnomeVFSFileInfo *info)
 
 
 /**
- * gnome_vfs_file_info_clear:
+ * gnome_vfs_file_info_clear
  * @info: Pointer to a file information struct
  * 
  * Clear @info so that it's ready to accept new data. This is
@@ -132,12 +131,13 @@ gnome_vfs_file_info_clear (GnomeVFSFileInfo *info)
 
 
 /**
- * gnome_vfs_file_info_get_mime_type:
+ * gnome_vfs_file_info_get_mime_type
  * @info: A pointer to a file information struct
  * 
- * Retrieve MIME type from @info.
+ * Retrieve MIME type from @info. There is no need to free the return
+ * value.
  * 
- * Return value: A pointer to a string representing the MIME type.
+ * Returns: A pointer to a string representing the MIME type.
  **/
 const gchar *
 gnome_vfs_file_info_get_mime_type (GnomeVFSFileInfo *info)
@@ -148,7 +148,7 @@ gnome_vfs_file_info_get_mime_type (GnomeVFSFileInfo *info)
 }
 
 /**
- * gnome_vfs_file_info_copy:
+ * gnome_vfs_file_info_copy
  * @dest: Pointer to a struct to copy @src's information into
  * @src: Pointer to the information to be copied into @dest
  * 
@@ -193,11 +193,12 @@ gnome_vfs_file_info_copy (GnomeVFSFileInfo *dest,
  * gnome_vfs_file_info_dup:
  * @orig: Pointer to a file information structure to duplicate
  * 
- * Returns a new file information struct that duplicates the information in @orig.
+ * Duplicates @orig and returns it.
+ * 
+ * Returns: a new file information struct that duplicates the information in @orig.
  **/
-
 GnomeVFSFileInfo *
-gnome_vfs_file_info_dup 	(const GnomeVFSFileInfo *orig)
+gnome_vfs_file_info_dup (const GnomeVFSFileInfo *orig)
 {
 	GnomeVFSFileInfo * ret;
 
@@ -212,9 +213,13 @@ gnome_vfs_file_info_dup 	(const GnomeVFSFileInfo *orig)
 
 
 /**
- * gnome_vfs_file_info_matches:
+ * gnome_vfs_file_info_matches
+ * @a: first GnomeVFSFileInfo struct to compare
+ * @b: second GnomeVFSFileInfo struct to compare
  *
  * Compare the two file info structs, return TRUE if they match.
+ *
+ * Returns: TRUE if the two GnomeVFSFileInfos match, otherwise return FALSE.
  **/
 gboolean
 gnome_vfs_file_info_matches (const GnomeVFSFileInfo *a,
@@ -240,9 +245,17 @@ gnome_vfs_file_info_matches (const GnomeVFSFileInfo *a,
 	}
 
 	g_assert (a->mime_type != NULL && b->mime_type != NULL);
-	return g_strcasecmp (a->mime_type, b->mime_type) == 0;
+	return g_ascii_strcasecmp (a->mime_type, b->mime_type) == 0;
 }
 
+/**
+ * gnome_vfs_file_info_list_ref:
+ * @list: list of GnomeVFSFileInfo elements
+ *
+ * Increments the reference count of the items in @list by one.
+ *
+ * Return value: @list
+ **/
 GList *
 gnome_vfs_file_info_list_ref (GList *list)
 {
@@ -250,6 +263,16 @@ gnome_vfs_file_info_list_ref (GList *list)
 	return list;
 }
 
+/**
+ * gnome_vfs_file_info_list_unref:
+ * @list: list of GnomeVFSFileInfo elements
+ *
+ * Decrements the reference count of the items in @list by one.
+ * Note that the list is *not freed* even if each member of the list
+ * is freed.
+ *
+ * Return value: @list
+ **/
 GList *
 gnome_vfs_file_info_list_unref (GList *list)
 {
@@ -257,12 +280,28 @@ gnome_vfs_file_info_list_unref (GList *list)
 	return list;
 }
 
+/**
+ * gnome_vfs_file_info_list_copy:
+ * @list: list of GnomeVFSFileInfo elements
+ *
+ * Creates a duplicate of @list, and references each member of
+ * that list.
+ *
+ * Return value: a newly referenced duplicate of @list
+ **/
 GList *
 gnome_vfs_file_info_list_copy (GList *list)
 {
 	return g_list_copy (gnome_vfs_file_info_list_ref (list));
 }
 
+/**
+ * gnome_vfs_file_info_list_free:
+ * @list: list of GnomeVFSFileInfo elements
+ *
+ * Decrements the reference count of each member of @list by one,
+ * and frees the list itself.
+ **/
 void
 gnome_vfs_file_info_list_free (GList *list)
 {
